lakatosSampleSize: Sample Size Calculation Using Lakatos Method for Survival Analysis
Description
Computes the required sample size and expected event numbers for two-group survival analysis
using Lakatos' method under exponential survival assumptions and varying weight functions (log-rank, Gehan, Tarone-Ware).